/*
 * J2ME Compass
 * Copyright (C) 2006 Dana Peters
 * http://www.qcontinuum.org/compass
 * 
 * Changed 2009 by Vedran Vidovic.
 * Removed henson.midp.Float class for performance reasons.
 * Removed code unused by SgTimer.
 */

package org.qcontinuum.astro;


public class EarthPosition {

  private double mLatitude;
  private double mLongitude;

  public EarthPosition(int latMinutes, int longMinutes) {
    mLatitude = latMinutes / 60.0;
    mLongitude = longMinutes / 60.0;
  }

  public EarthPosition(int latDegrees, int latMinutes, int longDegrees, int longMinutes) {
    mLatitude = latDegrees + (latMinutes / latDegrees < 0 ? -60 : 60);
    mLongitude = longDegrees + (longMinutes / longDegrees < 0 ? -60 : 60);
  }

  public EarthPosition(double latitude, double longitude) {
    mLatitude = latitude;
    mLongitude = longitude;
  }

  public int latTotalMinutes() {
    return (int) (mLatitude * 60);
  }

  public int longTotalMinutes() {
    return (int) (mLongitude * 60);
  }

  public double getLatitude() {
    return mLatitude;
  }

  public double getLongitude() {
    return mLongitude;
  }

  public String latString() {
    return Math.abs(latTotalMinutes() / 60) + "° " + (Math.abs(latTotalMinutes()) % 60) + "' "
        + ((latTotalMinutes() < 0) ? "S" : "N");
  }

  public String longString() {
    return Math.abs(longTotalMinutes() / 60) + "° " + (Math.abs(longTotalMinutes()) % 60) + "' "
        + ((longTotalMinutes() < 0) ? "W" : "E");
  }

  public String toString() {
    return latString() + ", " + longString();
  }

  public double getDistance(EarthPosition target) {
    double yMetres = Math.abs((mLongitude - target.mLongitude) * 111111); // 11111 = 10,000,000 / 90;
    double xMetres = Math.abs((mLatitude - target.mLatitude) * 111111) * (Math.cos(Math.toRadians(mLatitude)));
    return Math.sqrt(yMetres * yMetres + xMetres * xMetres);
  }

}
