package sg;

import javax.microedition.lcdui.Command;
import javax.microedition.lcdui.CommandListener;
import javax.microedition.lcdui.Display;
import javax.microedition.lcdui.Displayable;
import javax.microedition.lcdui.Form;
import javax.microedition.lcdui.TextField;

import org.qcontinuum.compass.Location;
import org.qcontinuum.compass.TimeZoneForm;

public class LocationForm extends Form implements CommandListener {
  private SgTimer sgTimer;
  private Displayable parentDisplayable;
  private Location location;

  private TextField nameField = new TextField("Location name:", "", 10, TextField.ANY);
  private TextField latDegField = new TextField("Latitude °:", "", 3, TextField.NUMERIC);
  private TextField latMinField = new TextField("Latitude ':", "", 2, TextField.NUMERIC);
  private TextField longDegField = new TextField("Longitude °:", "", 3, TextField.NUMERIC);
  private TextField longMinField = new TextField("Longitude ':", "", 2, TextField.NUMERIC);
  
  public LocationForm(final SgTimer sgTimer, final Displayable parentDisplayable, final Location location) {
    super("Location");
    this.sgTimer = sgTimer;
    this.parentDisplayable = parentDisplayable;
    this.location = location;
    
    this.append(nameField);
    this.append(latDegField);
    this.append(latMinField);
    this.append(longDegField);
    this.append(longMinField);
    
    addCommand(new Command("Ok", Command.OK, 1));
    addCommand(new Command("Back", Command.CANCEL, 2));

    setCommandListener(this);
  }
  
  public void init() {
    nameField.setString(location.Name);
    latDegField.setString(String.valueOf(location.getLatDegs()));
    latMinField.setString(String.valueOf(location.getLatMins()));
    longDegField.setString(String.valueOf(location.getLongDegs()));
    longMinField.setString(String.valueOf(location.getLongMins()));
  }

  public void commandAction(final Command command, final Displayable displayable) {
    switch (command.getCommandType()) {
      case Command.OK:
        String name = nameField.getString();
        String latDegStr = latDegField.getString();
        String latMinStr = latMinField.getString();
        String longDegStr = longDegField.getString();
        String longMinStr = longMinField.getString();
        
        if(name.length() > 0 &&
            latDegStr.length() > 0 && latMinStr.length() > 0 &&
            longDegStr.length() > 0 && longMinStr.length() > 0)
        {
          short latMin = readMin(latDegStr, latMinStr);
          short longMin = readMin(longDegStr, longMinStr);
          location.Name = name;
          location.LatMinutes = latMin;
          location.LongMinutes = longMin;
          TimeZoneForm timeZoneForm = new TimeZoneForm(sgTimer, this, location);
          Display.getDisplay(sgTimer).setCurrent(timeZoneForm);
        }
        else {
          SgTimer.showAlert("Please fill all fields.", this);
        }
        break;
      case Command.CANCEL:
        Display.getDisplay(sgTimer).setCurrent(parentDisplayable);
        break;
    }
  }
  
  private short readMin(final String degrees, final String minutes) {
    return (short)(60 * Short.parseShort(degrees) + Short.parseShort(minutes));
  }

}
